MLChem
===========

**MLChem** is machine-learning for chemistry.

This package is written in Python, and features:

- PyTorch backend.
- GPU support.
- ASE interface.
- Completely modular. You can use any part in your project.
- Free software <3. No secrets! Pull requests and additions more than welcome!
- Good documentation (I hope!).
- Explicit and idiomatic: `mlchem.get_me_a_coffee()`
